/*
 * Copyright (c) 2020, Oracle and/or its affiliates.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 *
 * 3. Neither the name of the copyright holder nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef TPM_BLOBS_H
#define TPM_BLOBS_H

#ifdef __cplusplus
extern "C" {
#endif

/*
 * The constants and data structures described in this file form part
 * of a stable interface between libtpms and QEMU. It is not possible
 * to update one without consideration of the other.
 */

#define TPMLIB_BLOB_MAGIC                   ((UINT32)0xb10b)
#define TPMLIB_BLOB_PCR_VALUES_VERSION_1    ((TPMLIB_BLOB_MAGIC << 16) | 0x1)
#define TPMLIB_BLOB_PCR_EVENT_LOG_VERSION_1 ((TPMLIB_BLOB_MAGIC << 16) | 0x1)

/*
 * PCR Values blob version 1 is encoded as follows:
 *
 * UINT32 version
 * UINT32 count of PCR values
 * [ UINT32 PCR number
 *   UINT32 count of digests
 *   [ UINT16 length of algorithm name (including NULL)
 *     [ BYTE algorithm name bytes
 *     ] x length of algorithm name
 *     UINT32 count of digest bytes
 *     [ BYTE digest byte
 *     ] x count of digest bytes
 *   ] x count of digests
 * ] x count of PCR values
 *
 * There no packing between elements.
 */

/*
 * PCR Event Log blob version 1 is encoded as follows:
 *
 * UINT32 version
 * UINT32 count of PCR event log entries
 * [ UINT32 PCR number
 *   UINT16 hash algorithm identifier
 *   UINT16 length of algorithm name (including NULL)
 *   [ BYTE algorithm name bytes
 *   ] x length of algorithm name
 *   UINT32 count of digest bytes
 *   [ BYTE digest byte
 *   ] x count of digest bytes
 *   UINT32 log entry sequence number
 * ] x count of PCR event log entries
 *
 * There is no packing between elements.
 */

#ifdef __cplusplus
}
#endif

#endif /* TPM_BLOBS_H */
